import os
from ..typing import sha256, Dict, get_type_hints

url = None
model = None
supports_stream = False
needs_auth = False
working = False

def _create_completion(model: str, messages: list, stream: bool, **kwargs):
    return


params = f'g4f.Providers.{os.path.basename(__file__)[:-3]} supports: ' + \
    '(%s)' % ', '.join(
        [f"{name}: {get_type_hints(_create_completion)[name].__name__}" for name in _create_completion.__code__.co_varnames[:_create_completion.__code__.co_argcount]])
